==> apache-storm-2.1.1-src.zip: apache-storm-2.1.1/storm-client/test/jvm/org/apache/storm/serialization/ThriftBridgeSerializationDelegateTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.serialization;

import java.io.Serializable;
import org.apache.storm.generated.ErrorInfo;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;


public class ThriftBridgeSerializationDelegateTest {

    SerializationDelegate testDelegate;

    @Before
    public void setUp() throws Exception {
        testDelegate = new ThriftSerializationDelegate();
        testDelegate.prepare(null);
    }

    @Test
    public void testThriftInstance() throws Exception {
        ErrorInfo errorInfo = new ErrorInfo();
        errorInfo.set_error("error");
        errorInfo.set_error_time_secs(1);
        errorInfo.set_host("host");
        errorInfo.set_port(1);

        byte[] serialized = new ThriftSerializationDelegate().serialize(errorInfo);
        ErrorInfo errorInfo2 = testDelegate.deserialize(serialized, ErrorInfo.class);
        assertEquals(errorInfo, errorInfo2);

        serialized = testDelegate.serialize(errorInfo);
        errorInfo2 = new ThriftSerializationDelegate().deserialize(serialized, ErrorInfo.class);
        assertEquals(errorInfo, errorInfo2);
    }

    static class TestPojo implements Serializable {
        String name;
        int age;
    }
}

==> apache-storm-2.8.3-src.zip: apache-storm-2.8.3/storm-client/test/jvm/org/apache/storm/serialization/ThriftBridgeSerializationDelegateTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.serialization;

import org.apache.storm.generated.ErrorInfo;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;


public class ThriftBridgeSerializationDelegateTest {

    SerializationDelegate testDelegate;

    @BeforeEach
    public void setUp() throws Exception {
        testDelegate = new ThriftSerializationDelegate();
        testDelegate.prepare(null);
    }

    @Test
    public void testThriftInstance() {
        ErrorInfo errorInfo = new ErrorInfo();
        errorInfo.set_error("error");
        errorInfo.set_error_time_secs(1);
        errorInfo.set_host("host");
        errorInfo.set_port(1);

        byte[] serialized = new ThriftSerializationDelegate().serialize(errorInfo);
        ErrorInfo errorInfo2 = testDelegate.deserialize(serialized, ErrorInfo.class);
        assertEquals(errorInfo, errorInfo2);

        serialized = testDelegate.serialize(errorInfo);
        errorInfo2 = new ThriftSerializationDelegate().deserialize(serialized, ErrorInfo.class);
        assertEquals(errorInfo, errorInfo2);
    }
}
